# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class RubyAdjust(metaclass=UnoEnumMeta, type_name="com.sun.star.text.RubyAdjust", name_space="com.sun.star.text"):
        """Dynamically created class that represents ``com.sun.star.text.RubyAdjust`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.text.RubyAdjust import BLOCK as RUBY_ADJUST_BLOCK
        from com.sun.star.text.RubyAdjust import CENTER as RUBY_ADJUST_CENTER
        from com.sun.star.text.RubyAdjust import INDENT_BLOCK as RUBY_ADJUST_INDENT_BLOCK
        from com.sun.star.text.RubyAdjust import LEFT as RUBY_ADJUST_LEFT
        from com.sun.star.text.RubyAdjust import RIGHT as RUBY_ADJUST_RIGHT

        class RubyAdjust(uno.Enum):
            """
            Enum Class


            See Also:
                `API RubyAdjust <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#adf417fe4b45f486fe88af93ad0b59efb>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.text.RubyAdjust', value)

            __ooo_ns__: str = 'com.sun.star.text'
            __ooo_full_ns__: str = 'com.sun.star.text.RubyAdjust'
            __ooo_type_name__: str = 'enum'

            BLOCK = RUBY_ADJUST_BLOCK
            """
            adjusted to both borders / stretched
            """
            CENTER = RUBY_ADJUST_CENTER
            """
            the object is adjusted to the center.

            centric adjusted.
            """
            INDENT_BLOCK = RUBY_ADJUST_INDENT_BLOCK
            """
            adjusted to both borders except for a small indent on both sides
            """
            LEFT = RUBY_ADJUST_LEFT
            """
            the object is left adjusted.

            text flows to the left side of the object.

            adjusted to the left.
            """
            RIGHT = RUBY_ADJUST_RIGHT
            """
            the object is right adjusted.

            text flows to the right side of the object.

            adjusted to the right.
            """
    else:
        # keep document generators happy
        from ...lo.text.ruby_adjust import RubyAdjust as RubyAdjust


__all__ = ['RubyAdjust']
