# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from ..container.x_container_query import XContainerQuery as XContainerQuery_1cdd0edc
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from .x_type_detection import XTypeDetection as XTypeDetection_ff7e0e00
from ..util.x_flushable import XFlushable as XFlushable_9a420ab4

class TypeDetection(XContainerQuery_1cdd0edc, XNameContainer_cb90e47, XTypeDetection_ff7e0e00, XFlushable_9a420ab4):
    """
    Service Class

    encapsulate a type detection service and provide read/write access on it's configuration data.
    
    It's possible to make a \"flat\" detection which may use internal configuration data only - or a \"deep\" detection which use special ExtendedTypeDetection services to look into the document stream. Last mode can be suppressed to perform the operation. Of course the results can't be guaranteed then. (e.g. in case the extension was changed)

    See Also:
        `API TypeDetection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1TypeDetection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.TypeDetection'
    __ooo_type_name__: str = 'service'


__all__ = ['TypeDetection']

