# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class FastAttribute(object):
    """
    Struct Class

    A struct to keep information of an element's attribute.

    See Also:
        `API FastAttribute <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1FastAttribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.FastAttribute'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.FastAttribute'
    """Literal Constant ``com.sun.star.xml.FastAttribute``"""

    def __init__(self, Token: typing.Optional[int] = 0, Value: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Token (int, optional): Token value.
            Value (str, optional): Value value.
        """
        super().__init__()

        if isinstance(Token, FastAttribute):
            oth: FastAttribute = Token
            self.Token = oth.Token
            self.Value = oth.Value
            return

        kargs = {
            "Token": Token,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._token = kwargs["Token"]
        self._value = kwargs["Value"]


    @property
    def Token(self) -> int:
        """
        the token corresponding to the attribute
        """
        return self._token

    @Token.setter
    def Token(self, value: int) -> None:
        self._token = value

    @property
    def Value(self) -> str:
        """
        the attribute value
        """
        return self._value

    @Value.setter
    def Value(self, value: str) -> None:
        self._value = value


__all__ = ['FastAttribute']
