# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.reflection.core_reflection import CoreReflection as CoreReflection
from ...lo.reflection.field_access_mode import FieldAccessMode as FieldAccessMode
from ...lo.reflection.invalid_type_name_exception import InvalidTypeNameException as InvalidTypeNameException
from ...lo.reflection.invocation_target_exception import InvocationTargetException as InvocationTargetException
from ...lo.reflection.method_mode import MethodMode as MethodMode
from ...lo.reflection.no_such_type_name_exception import NoSuchTypeNameException as NoSuchTypeNameException
from ...lo.reflection.param_info import ParamInfo as ParamInfo
from ...lo.reflection.param_mode import ParamMode as ParamMode
from ...lo.reflection.proxy_factory import ProxyFactory as ProxyFactory
from ...lo.reflection.type_description_manager import TypeDescriptionManager as TypeDescriptionManager
from ...lo.reflection.type_description_provider import TypeDescriptionProvider as TypeDescriptionProvider
from ...lo.reflection.type_description_search_depth import TypeDescriptionSearchDepth as TypeDescriptionSearchDepth
from ...lo.reflection.x_array_type_description import XArrayTypeDescription as XArrayTypeDescription
from ...lo.reflection.x_compound_type_description import XCompoundTypeDescription as XCompoundTypeDescription
from ...lo.reflection.x_constant_type_description import XConstantTypeDescription as XConstantTypeDescription
from ...lo.reflection.x_constants_type_description import XConstantsTypeDescription as XConstantsTypeDescription
from ...lo.reflection.x_enum_type_description import XEnumTypeDescription as XEnumTypeDescription
from ...lo.reflection.x_idl_array import XIdlArray as XIdlArray
from ...lo.reflection.x_idl_class import XIdlClass as XIdlClass
from ...lo.reflection.x_idl_class_provider import XIdlClassProvider as XIdlClassProvider
from ...lo.reflection.x_idl_field import XIdlField as XIdlField
from ...lo.reflection.x_idl_field2 import XIdlField2 as XIdlField2
from ...lo.reflection.x_idl_member import XIdlMember as XIdlMember
from ...lo.reflection.x_idl_method import XIdlMethod as XIdlMethod
from ...lo.reflection.x_idl_reflection import XIdlReflection as XIdlReflection
from ...lo.reflection.x_indirect_type_description import XIndirectTypeDescription as XIndirectTypeDescription
from ...lo.reflection.x_interface_attribute_type_description import XInterfaceAttributeTypeDescription as XInterfaceAttributeTypeDescription
from ...lo.reflection.x_interface_attribute_type_description2 import XInterfaceAttributeTypeDescription2 as XInterfaceAttributeTypeDescription2
from ...lo.reflection.x_interface_member_type_description import XInterfaceMemberTypeDescription as XInterfaceMemberTypeDescription
from ...lo.reflection.x_interface_method_type_description import XInterfaceMethodTypeDescription as XInterfaceMethodTypeDescription
from ...lo.reflection.x_interface_type_description import XInterfaceTypeDescription as XInterfaceTypeDescription
from ...lo.reflection.x_interface_type_description2 import XInterfaceTypeDescription2 as XInterfaceTypeDescription2
from ...lo.reflection.x_method_parameter import XMethodParameter as XMethodParameter
from ...lo.reflection.x_module_type_description import XModuleTypeDescription as XModuleTypeDescription
from ...lo.reflection.x_parameter import XParameter as XParameter
from ...lo.reflection.x_property_type_description import XPropertyTypeDescription as XPropertyTypeDescription
from ...lo.reflection.x_proxy_factory import XProxyFactory as XProxyFactory
from ...lo.reflection.x_published import XPublished as XPublished
from ...lo.reflection.x_service_constructor_description import XServiceConstructorDescription as XServiceConstructorDescription
from ...lo.reflection.x_service_type_description import XServiceTypeDescription as XServiceTypeDescription
from ...lo.reflection.x_service_type_description2 import XServiceTypeDescription2 as XServiceTypeDescription2
from ...lo.reflection.x_singleton_type_description import XSingletonTypeDescription as XSingletonTypeDescription
from ...lo.reflection.x_singleton_type_description2 import XSingletonTypeDescription2 as XSingletonTypeDescription2
from ...lo.reflection.x_struct_type_description import XStructTypeDescription as XStructTypeDescription
from ...lo.reflection.x_type_description import XTypeDescription as XTypeDescription
from ...lo.reflection.x_type_description_enumeration import XTypeDescriptionEnumeration as XTypeDescriptionEnumeration
from ...lo.reflection.x_type_description_enumeration_access import XTypeDescriptionEnumerationAccess as XTypeDescriptionEnumerationAccess
from ...lo.reflection.x_union_type_description import XUnionTypeDescription as XUnionTypeDescription
from ...lo.reflection.the_core_reflection import theCoreReflection as theCoreReflection
