# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.inspection
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2

class XPropertyControlFactory(ABC):
    """
    a factory for XPropertyControls
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XPropertyControlFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyControlFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.XPropertyControlFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.inspection.XPropertyControlFactory'

    @abstractmethod
    def createPropertyControl(self, ControlType: int, CreateReadOnly: bool) -> XPropertyControl_3f260fe2:
        """
        creates a XPropertyControl
        
        A XPropertyControlFactory can create any of the control types denoted by the PropertyControlType constants.
        
        If this argument is TRUE, this does not necessarily mean that the property cannot be changed at all in the ObjectInspector. Instead, an XPropertyHandler can still decide that there is a dedicated UI for entering the property value, which is usually triggered by a LineDescriptor.PrimaryButton.
        
        Note that this parameter might be ignored if the XObjectInspectorModel.IsReadOnly attribute is TRUE, in which case all created property controls must be readonly.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XPropertyControlFactory']

