# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.ui.dialogs.address_book_source_pilot import AddressBookSourcePilot as AddressBookSourcePilot
from ....lo.ui.dialogs.common_file_picker_element_ids import CommonFilePickerElementIds as CommonFilePickerElementIds
from ....lo.ui.dialogs.control_actions import ControlActions as ControlActions
from ....lo.ui.dialogs.dialog_closed_event import DialogClosedEvent as DialogClosedEvent
from ....lo.ui.dialogs.executable_dialog_exception import ExecutableDialogException as ExecutableDialogException
from ....lo.ui.dialogs.executable_dialog_results import ExecutableDialogResults as ExecutableDialogResults
from ....lo.ui.dialogs.extended_file_picker_element_ids import ExtendedFilePickerElementIds as ExtendedFilePickerElementIds
from ....lo.ui.dialogs.file_picker import FilePicker as FilePicker
from ....lo.ui.dialogs.file_picker_event import FilePickerEvent as FilePickerEvent
from ....lo.ui.dialogs.file_preview_image_formats import FilePreviewImageFormats as FilePreviewImageFormats
from ....lo.ui.dialogs.filter_options_dialog import FilterOptionsDialog as FilterOptionsDialog
from ....lo.ui.dialogs.folder_picker import FolderPicker as FolderPicker
from ....lo.ui.dialogs.listbox_control_actions import ListboxControlActions as ListboxControlActions
from ....lo.ui.dialogs.template_description import TemplateDescription as TemplateDescription
from ....lo.ui.dialogs.wizard import Wizard as Wizard
from ....lo.ui.dialogs.wizard_button import WizardButton as WizardButton
from ....lo.ui.dialogs.wizard_travel_type import WizardTravelType as WizardTravelType
from ....lo.ui.dialogs.x_asynchronous_executable_dialog import XAsynchronousExecutableDialog as XAsynchronousExecutableDialog
from ....lo.ui.dialogs.x_control_access import XControlAccess as XControlAccess
from ....lo.ui.dialogs.x_control_information import XControlInformation as XControlInformation
from ....lo.ui.dialogs.x_dialog_closed_listener import XDialogClosedListener as XDialogClosedListener
from ....lo.ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog
from ....lo.ui.dialogs.x_file_picker import XFilePicker as XFilePicker
from ....lo.ui.dialogs.x_file_picker2 import XFilePicker2 as XFilePicker2
from ....lo.ui.dialogs.x_file_picker3 import XFilePicker3 as XFilePicker3
from ....lo.ui.dialogs.x_file_picker_control_access import XFilePickerControlAccess as XFilePickerControlAccess
from ....lo.ui.dialogs.x_file_picker_listener import XFilePickerListener as XFilePickerListener
from ....lo.ui.dialogs.x_file_picker_notifier import XFilePickerNotifier as XFilePickerNotifier
from ....lo.ui.dialogs.x_file_preview import XFilePreview as XFilePreview
from ....lo.ui.dialogs.x_filter_group_manager import XFilterGroupManager as XFilterGroupManager
from ....lo.ui.dialogs.x_filter_manager import XFilterManager as XFilterManager
from ....lo.ui.dialogs.x_folder_picker import XFolderPicker as XFolderPicker
from ....lo.ui.dialogs.x_folder_picker2 import XFolderPicker2 as XFolderPicker2
from ....lo.ui.dialogs.xslt_filter_dialog import XSLTFilterDialog as XSLTFilterDialog
from ....lo.ui.dialogs.x_wizard import XWizard as XWizard
from ....lo.ui.dialogs.x_wizard_controller import XWizardController as XWizardController
from ....lo.ui.dialogs.x_wizard_page import XWizardPage as XWizardPage
