# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.ui.ContextMenuInterceptorAction import ContextMenuInterceptorActionProto

class ContextMenuInterceptorAction(Enum):
    """
    Enum Class


    See Also:
        `API ContextMenuInterceptorAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui.html#a6e0452a8960be949dce52c427920ebbe>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ContextMenuInterceptorAction'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.ui.ContextMenuInterceptorAction'

    CANCELLED = cast("ContextMenuInterceptorActionProto", 'CANCELLED')
    """
    the context menu must not be executed.
    
    The next registered XContextMenuInterceptor should not be notified.
    """
    CONTINUE_MODIFIED = cast("ContextMenuInterceptorActionProto", 'CONTINUE_MODIFIED')
    """
    the menu has been modified and the next registered XContextMenuInterceptor should be notified.
    """
    EXECUTE_MODIFIED = cast("ContextMenuInterceptorActionProto", 'EXECUTE_MODIFIED')
    """
    the menu has been modified and should be executed without notifying the next registered XContextMenuInterceptor.
    """
    IGNORED = cast("ContextMenuInterceptorActionProto", 'IGNORED')
    """
    the XContextMenuInterceptor has ignored the call.
    
    The next registered XContextMenuInterceptor should be notified.
    """

__all__ = ['ContextMenuInterceptorAction']

