# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.image
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..document.x_events_supplier import XEventsSupplier as XEventsSupplier_ecd0e88

class ImageMapObject(XPropertySet_bc180bfa, XEventsSupplier_ecd0e88):
    """
    Service Class

    this is a base service for objects inside an image map.

    See Also:
        `API ImageMapObject <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1image_1_1ImageMapObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.image'
    __ooo_full_ns__: str = 'com.sun.star.image.ImageMapObject'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Description(self) -> str:
        """
        This is an optional description text for the link.
        """
        ...

    @abstractproperty
    def IsActive(self) -> bool:
        """
        If an object is not active, it is ignored when the user clicks on the ImageMap.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        Optionally, objects could be named.
        """
        ...

    @abstractproperty
    def Target(self) -> str:
        """
        This is the target frame.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        This is the URL for this object.
        """
        ...


__all__ = ['ImageMapObject']

