# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import uno
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XCipherContext(XInterface_8f010a43):
    """
    This interface allows to encrypt/decrypt data using the cipher context.
    
    The algorithm as well as encryption data are specified on object creation.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XCipherContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XCipherContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XCipherContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XCipherContext'

    @abstractmethod
    def convertWithCipherContext(self, aData: uno.ByteSequence) -> uno.ByteSequence:
        """
        encrypts/decrypts the data using the cipher.
        
        Please have in mind, the cipher object state might depend from the already encrypted/decrypted data ( it depends from the used algorithm ).
        
        Whether the object does encryption or decryption is specified by creation of the object.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.DisposedException: ``DisposedException``
        """
        ...
    @abstractmethod
    def finalizeCipherContextAndDispose(self) -> uno.ByteSequence:
        """
        finalizes cipher and disposes context.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
        """
        ...

__all__ = ['XCipherContext']

