# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from .x_relative_text_content_insert import XRelativeTextContentInsert as XRelativeTextContentInsert_7dca1156
from .x_text import XText as XText_690408ca
from .x_text_range_compare import XTextRangeCompare as XTextRangeCompare_f04e0d7e
from .x_text_range_mover import XTextRangeMover as XTextRangeMover_d5ff0cc0
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6

class Text(XEnumerationAccess_4bac0ffc, XRelativeTextContentInsert_7dca1156, XText_690408ca, XTextRangeCompare_f04e0d7e, XTextRangeMover_d5ff0cc0):
    """
    Service Class

    is an independent piece of text which consists of a series of one or more paragraphs.
    
    This service is used, for example, for the text of a TextDocument or the text in a cell or TextFrame.

    See Also:
        `API Text <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1Text.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.Text'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def EndRedline(self) -> PropertyValues_d6470ce6:
        """
        contains the properties of a redline at the start of the document.
        
        The sequence contains the following properties
        """
        ...

    @abstractproperty
    def StartRedline(self) -> PropertyValues_d6470ce6:
        """
        contains the properties of a redline at the start of the document.
        
        The sequence contains the following properties
        """
        ...


__all__ = ['Text']

