# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.mozilla.menu_multiple_change import MenuMultipleChange as MenuMultipleChange
from ...lo.mozilla.menu_proxy import MenuProxy as MenuProxy
from ...lo.mozilla.menu_proxy_listener import MenuProxyListener as MenuProxyListener
from ...lo.mozilla.menu_single_change import MenuSingleChange as MenuSingleChange
from ...lo.mozilla.mozilla_bootstrap import MozillaBootstrap as MozillaBootstrap
from ...lo.mozilla.mozilla_product_type import MozillaProductType as MozillaProductType
from ...lo.mozilla.x_close_session_listener import XCloseSessionListener as XCloseSessionListener
from ...lo.mozilla.x_code_proxy import XCodeProxy as XCodeProxy
from ...lo.mozilla.x_menu_proxy import XMenuProxy as XMenuProxy
from ...lo.mozilla.x_menu_proxy_listener import XMenuProxyListener as XMenuProxyListener
from ...lo.mozilla.x_mozilla_bootstrap import XMozillaBootstrap as XMozillaBootstrap
from ...lo.mozilla.x_profile_discover import XProfileDiscover as XProfileDiscover
from ...lo.mozilla.x_profile_manager import XProfileManager as XProfileManager
from ...lo.mozilla.x_proxy_runner import XProxyRunner as XProxyRunner
