# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.presentation.ClickAction import ClickActionProto

class ClickAction(Enum):
    """
    Enum Class


    See Also:
        `API ClickAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8f>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.ClickAction'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.presentation.ClickAction'

    BOOKMARK = cast("ClickActionProto", 'BOOKMARK')
    """
    The presentation jumps to a bookmark.
    """
    DOCUMENT = cast("ClickActionProto", 'DOCUMENT')
    """
    The presentation jumps to another document.
    """
    FIRSTPAGE = cast("ClickActionProto", 'FIRSTPAGE')
    """
    The presentation continues with the first page.
    """
    INVISIBLE = cast("ClickActionProto", 'INVISIBLE')
    """
    The object renders itself invisible after a click.
    """
    LASTPAGE = cast("ClickActionProto", 'LASTPAGE')
    """
    The presentation continues with the last page.
    """
    MACRO = cast("ClickActionProto", 'MACRO')
    """
    A star basic macro is executed after the click.
    """
    NEXTPAGE = cast("ClickActionProto", 'NEXTPAGE')
    """
    The presentation jumps to the next page.
    """
    NONE = cast("ClickActionProto", 'NONE')
    """
    use no animation effects.
    
    use no fade effects.
    
    No action is performed on click.
    """
    PREVPAGE = cast("ClickActionProto", 'PREVPAGE')
    """
    The presentation jumps to the previous page.
    """
    PROGRAM = cast("ClickActionProto", 'PROGRAM')
    """
    Another program is executed after a click.
    """
    SOUND = cast("ClickActionProto", 'SOUND')
    """
    A sound is played after a click.
    """
    STOPPRESENTATION = cast("ClickActionProto", 'STOPPRESENTATION')
    """
    The presentation is stopped after the click.
    """
    VANISH = cast("ClickActionProto", 'VANISH')
    """
    The object vanishes with its effect.
    """
    VERB = cast("ClickActionProto", 'VERB')
    """
    An OLE verb is performed on this object.
    """

__all__ = ['ClickAction']

