# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class ConditionFormatOperator(object):
    """
    Const Class


    See Also:
        `API ConditionFormatOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.ConditionFormatOperator'
    __ooo_type_name__: str = 'const'

    EQUAL = 0
    LESS = 1
    GREATER = 2
    LESS_EQUAL = 3
    GREATER_EQUAL = 4
    NOT_EQUAL = 5
    BETWEEN = 6
    NOT_BETWEEN = 7
    DUPLICATE = 8
    UNIQUE = 9
    TOP_N_ELEMENTS = 10
    BOTTOM_N_ELEMENTS = 11
    TOP_N_PERCENT = 12
    BOTTOM_N_PERCENT = 13
    ABOVE_AVERAGE = 14
    BELOW_AVERAGE = 15
    ABOVE_EQUAL_AVERAGE = 16
    BELOW_EQUAL_AVERAGE = 17
    ERROR = 18
    NO_ERROR = 19
    BEGINS_WITH = 20
    ENDS_WITH = 21
    CONTAINS = 22
    NOT_CONTAINS = 23
    EXPRESSION = 24

__all__ = ['ConditionFormatOperator']
