# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TextureKind(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.TextureKind", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.TextureKind`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.TextureKind import COLOR as TEXTURE_KIND_COLOR
        from com.sun.star.drawing.TextureKind import LUMINANCE as TEXTURE_KIND_LUMINANCE

        class TextureKind(uno.Enum):
            """
            Enum Class


            See Also:
                `API TextureKind <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a36a384629c2a5cfb1a9d019d30923c2b>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.TextureKind', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.TextureKind'
            __ooo_type_name__: str = 'enum'

            COLOR = TEXTURE_KIND_COLOR
            """
            With this mode the lighting is ignored and only the texture color information is used.

            With this mode, the lighting is ignored and only the texture color information is used.
            """
            LUMINANCE = TEXTURE_KIND_LUMINANCE
            """
            With TextureKind LUMINANCE, the texture and the lighting information is mixed to produce the image, so a lit, textured object is achieved.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.texture_kind import TextureKind as TextureKind


__all__ = ['TextureKind']
