# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_singleton_type_description import XSingletonTypeDescription as XSingletonTypeDescription_db781364
if typing.TYPE_CHECKING:
    from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XSingletonTypeDescription2(XSingletonTypeDescription_db781364):
    """
    Reflects a singleton, supporting interface-based singletons.
    
    This type supersedes XSingletonTypeDescription, which only supports obsolete, service-based singletons.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XSingletonTypeDescription2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XSingletonTypeDescription2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XSingletonTypeDescription2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XSingletonTypeDescription2'

    @abstractmethod
    def getInterface(self) -> XTypeDescription_3c210fb1:
        """
        Returns the interface type associated with the singleton.
        """
        ...
    @abstractmethod
    def isInterfaceBased(self) -> bool:
        """
        Returns whether this object reflects an interface-based singleton.
        """
        ...

__all__ = ['XSingletonTypeDescription2']

