# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from ..accessibility.x_accessible_component import XAccessibleComponent as XAccessibleComponent_b2f21269
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b

class AccessibleChartDocumentView(XAccessible_1cbc0eb6, XAccessibleComponent_b2f21269, XAccessibleContext_8eae119b):
    """
    Service Class

    The AccessibleChartDocumentView service is supported by a Component that represents the view of a Chart document to provide an entry point to the document tree for accessibility.
    
    An object that implements the AccessibleChartDocumentView service provides information about itself and about the chart subcomponents contained in the chart document displayed in a window. This service gives a simplified view on the underlying implementation. It tries both to keep the structure of the accessibility representation tree as simple as possible and provide as much relevant information as possible.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleChartDocumentView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1AccessibleChartDocumentView.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.AccessibleChartDocumentView'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleChartDocumentView']

