# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty
from .base_index import BaseIndex as BaseIndex_8f0d0a40

class IllustrationsIndex(BaseIndex_8f0d0a40):
    """
    Service Class

    specifies service of illustration indexes within a document.

    See Also:
        `API IllustrationsIndex <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1IllustrationsIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.IllustrationsIndex'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CreateFromLabels(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def LabelCategory(self) -> str:
        """
        """
        ...

    @abstractproperty
    def LabelDisplayType(self) -> int:
        """
        """
        ...


__all__ = ['IllustrationsIndex']

