# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..accessibility.x_accessible_action import XAccessibleAction as XAccessibleAction_7ccc1114
from .accessible_shape import AccessibleShape as AccessibleShape_fdd20dd3

class AccessibleOLEShape(AccessibleShape_fdd20dd3, XAccessibleAction_7ccc1114):
    """
    Service Class

    The AccessibleOLEShape service is implemented by OLE shapes.
    
    This includes generic OLE shapes, frames, plug-ins, and applets.
    
    This service supports the additional com.sun.star.accessibility.XAccessibleAction interface.
    
    OLE objects are handled as place holders. While not activated the accessible OLE shape is the only indicator of the OLE object's existence. When an OLE object has been activated then the accessibility tree representing it (as far as that is available) is included directly under the accessible document view and not under the OLE object. This is due to underlying implementation constraints and may change in the future.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleOLEShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleOLEShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AccessibleOLEShape'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleOLEShape']

