# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report.inspection
from __future__ import annotations
from abc import abstractmethod
from ...inspection.x_object_inspector_model import XObjectInspectorModel as XObjectInspectorModel_9077119b

class DefaultComponentInspectorModel(XObjectInspectorModel_9077119b):
    """
    Service Class

    implements a com.sun.star.inspection.XObjectInspectorModel for inspecting form components, in particular all components implementing the ReportComponent service.
    
    A DefaultComponentInspectorModel provides the following handlers by default:
    
    **since**
    
        OOo 2.2

    See Also:
        `API DefaultComponentInspectorModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1report_1_1inspection_1_1DefaultComponentInspectorModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report.inspection'
    __ooo_full_ns__: str = 'com.sun.star.report.inspection.DefaultComponentInspectorModel'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createDefault(self) -> None:
        """
        creates a default DefaultComponentInspectorModel, providing factories for all handlers listed above.
        
        **since**
        
            OOo 2.2
        """
        ...
    @abstractmethod
    def createWithHelpSection(self, minHelpTextLines: int, maxHelpTextLines: int) -> None:
        """
        creates a default DefaultComponentInspectorModel, providing factories for all handlers listed above, and describing an ObjectInspector which has a help section.
        
        **since**
        
            OOo 2.2

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['DefaultComponentInspectorModel']

