# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.smarttags
from __future__ import annotations
from .x_smart_tag_recognizer import XSmartTagRecognizer as XSmartTagRecognizer_5ccd1071

class SmartTagRecognizer(XSmartTagRecognizer_5ccd1071):
    """
    Service Class

    recognizes smart tags.
    
    Implementations of this service are used to scan the document text for smart tags. Smart tags are pieces of text that can be associated with specific actions which are defined by implementations of the SmartTagAction service.
    
    **since**
    
        OOo 2.3

    See Also:
        `API SmartTagRecognizer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1smarttags_1_1SmartTagRecognizer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.smarttags'
    __ooo_full_ns__: str = 'com.sun.star.smarttags.SmartTagRecognizer'
    __ooo_type_name__: str = 'service'


__all__ = ['SmartTagRecognizer']

