# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class IconSetType(object):
    """
    Const Class


    See Also:
        `API IconSetType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.IconSetType'
    __ooo_type_name__: str = 'const'

    ICONSET_3ARROWS = 0
    ICONSET_3ARROWS_GRAY = 1
    ICONSET_3FLAGS = 2
    ICONSET_3TRAFFICLIGHTS1 = 3
    ICONSET_3TRAFFICLIGHTS2 = 4
    ICONSET_3SIGNS = 5
    ICONSET_3SYMBOLS = 6
    ICONSET_3SYMBOLS2 = 7
    ICONSET_3SMILIES = 8
    ICONSET_3COLOR_SIMILIES = 9
    ICONSET_4ARROWS = 10
    ICONSET_4ARROWS_GRAY = 11
    ICONSET_4RED_TO_BLACK = 12
    ICONSET_4RATING = 13
    ICONSET_4TRAFFICLIGHTS = 14
    ICONSET_5ARROWS = 15
    ICONSET_5ARROWS_GRAY = 16
    ICONSET_5RATINGS = 17
    ICONSET_5QUARTERS = 18

__all__ = ['IconSetType']
