# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XInteractionHandlerSupplier(XInterface_8f010a43):
    """
    This interface should be implemented by an internal XCommandEnvironment that can not supply an com.sun.star.task.XInteractionHandler, but instead wants interaction requests to be handled by other internal error handling mechanism.

    See Also:
        `API XInteractionHandlerSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XInteractionHandlerSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XInteractionHandlerSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XInteractionHandlerSupplier'

    @abstractmethod
    def hasInteractionHandler(self) -> bool:
        """
        Returns whether an com.sun.star.task.XInteractionHandler can be supplied.
        """
        ...

__all__ = ['XInteractionHandlerSupplier']

