# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class PanoseSerifStyle(object):
    """
    Const Class


    See Also:
        `API PanoseSerifStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1PanoseSerifStyle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.PanoseSerifStyle'
    __ooo_type_name__: str = 'const'

    ANYTHING = 0
    NO_FIT = 1
    COVE = 2
    OBTUSE_COVE = 3
    SQUARE_COVE = 4
    OBTUSE_SQUARE_COVE = 5
    SQUARE = 6
    THIN = 7
    BONE = 8
    EXAGGERATED = 9
    TRIANGLE = 10
    NORMAL_SANS = 11
    OBTUSE_SANS = 12
    PERP_SANS = 13
    FLARED = 14
    ROUNDED = 15

__all__ = ['PanoseSerifStyle']
