# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.ucb.ContentCreationError import ContentCreationErrorProto

class ContentCreationError(Enum):
    """
    Enum Class


    See Also:
        `API ContentCreationError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#aa2e437022c4d519cf5488a06e5e81ef4>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.ContentCreationError'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.ucb.ContentCreationError'

    CONTENT_CREATION_FAILED = cast("ContentCreationErrorProto", 'CONTENT_CREATION_FAILED')
    """
    Provider was unable to create the content instance.
    """
    IDENTIFIER_CREATION_FAILED = cast("ContentCreationErrorProto", 'IDENTIFIER_CREATION_FAILED')
    """
    Creation of content identifier failed.
    """
    NO_CONTENT_BROKER = cast("ContentCreationErrorProto", 'NO_CONTENT_BROKER')
    """
    """
    NO_CONTENT_PROVIDER = cast("ContentCreationErrorProto", 'NO_CONTENT_PROVIDER')
    """
    No Content Provider for given content identifier available.
    """
    NO_IDENTIFIER_FACTORY = cast("ContentCreationErrorProto", 'NO_IDENTIFIER_FACTORY')
    """
    """
    UNKNOWN = cast("ContentCreationErrorProto", 'UNKNOWN')
    """
    Unknown.
    
    An unknown I/O error has occurred.
    """

__all__ = ['ContentCreationError']

