# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.java.invalid_java_settings_exception import InvalidJavaSettingsException as InvalidJavaSettingsException
from ...lo.java.java_disabled_exception import JavaDisabledException as JavaDisabledException
from ...lo.java.java_initialization_exception import JavaInitializationException as JavaInitializationException
from ...lo.java.java_not_configured_exception import JavaNotConfiguredException as JavaNotConfiguredException
from ...lo.java.java_not_found_exception import JavaNotFoundException as JavaNotFoundException
from ...lo.java.java_vm_creation_failure_exception import JavaVMCreationFailureException as JavaVMCreationFailureException
from ...lo.java.java_virtual_machine import JavaVirtualMachine as JavaVirtualMachine
from ...lo.java.missing_java_runtime_exception import MissingJavaRuntimeException as MissingJavaRuntimeException
from ...lo.java.restart_required_exception import RestartRequiredException as RestartRequiredException
from ...lo.java.wrong_java_version_exception import WrongJavaVersionException as WrongJavaVersionException
from ...lo.java.x_java_thread_register_11 import XJavaThreadRegister_11 as XJavaThreadRegister_11
from ...lo.java.x_java_vm import XJavaVM as XJavaVM
