# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.lang.array_index_out_of_bounds_exception import ArrayIndexOutOfBoundsException as ArrayIndexOutOfBoundsException
from ...lo.lang.class_not_found_exception import ClassNotFoundException as ClassNotFoundException
from ...lo.lang.disposed_exception import DisposedException as DisposedException
from ...lo.lang.event_object import EventObject as EventObject
from ...lo.lang.illegal_access_exception import IllegalAccessException as IllegalAccessException
from ...lo.lang.illegal_argument_exception import IllegalArgumentException as IllegalArgumentException
from ...lo.lang.index_out_of_bounds_exception import IndexOutOfBoundsException as IndexOutOfBoundsException
from ...lo.lang.invalid_listener_exception import InvalidListenerException as InvalidListenerException
from ...lo.lang.listener_exist_exception import ListenerExistException as ListenerExistException
from ...lo.lang.locale import Locale as Locale
from ...lo.lang.multi_service_factory import MultiServiceFactory as MultiServiceFactory
from ...lo.lang.no_such_field_exception import NoSuchFieldException as NoSuchFieldException
from ...lo.lang.no_such_method_exception import NoSuchMethodException as NoSuchMethodException
from ...lo.lang.no_support_exception import NoSupportException as NoSupportException
from ...lo.lang.not_initialized_exception import NotInitializedException as NotInitializedException
from ...lo.lang.null_pointer_exception import NullPointerException as NullPointerException
from ...lo.lang.registry_service_manager import RegistryServiceManager as RegistryServiceManager
from ...lo.lang.service_manager import ServiceManager as ServiceManager
from ...lo.lang.service_not_registered_exception import ServiceNotRegisteredException as ServiceNotRegisteredException
from ...lo.lang.system_dependent import SystemDependent as SystemDependent
from ...lo.lang.wrapped_target_exception import WrappedTargetException as WrappedTargetException
from ...lo.lang.wrapped_target_runtime_exception import WrappedTargetRuntimeException as WrappedTargetRuntimeException
from ...lo.lang.x_component import XComponent as XComponent
from ...lo.lang.x_connection_point import XConnectionPoint as XConnectionPoint
from ...lo.lang.x_connection_point_container import XConnectionPointContainer as XConnectionPointContainer
from ...lo.lang.x_event_listener import XEventListener as XEventListener
from ...lo.lang.x_initialization import XInitialization as XInitialization
from ...lo.lang.x_localizable import XLocalizable as XLocalizable
from ...lo.lang.x_main import XMain as XMain
from ...lo.lang.x_multi_component_factory import XMultiComponentFactory as XMultiComponentFactory
from ...lo.lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory
from ...lo.lang.x_service_display_name import XServiceDisplayName as XServiceDisplayName
from ...lo.lang.x_service_info import XServiceInfo as XServiceInfo
from ...lo.lang.x_service_name import XServiceName as XServiceName
from ...lo.lang.x_single_component_factory import XSingleComponentFactory as XSingleComponentFactory
from ...lo.lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory
from ...lo.lang.x_type_provider import XTypeProvider as XTypeProvider
from ...lo.lang.x_uno_tunnel import XUnoTunnel as XUnoTunnel
