# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from .x_pipe import XPipe as XPipe_567d07c6

class Pipe(XPipe_567d07c6):
    """
    Service Class

    the implementation of an output stream and an input stream.
    
    All data written through the outputstream is buffered until it is read again from the input stream. Often two different threads access input and outputstream.
    
    With the pipe-service, an outputstream can be converted into an input stream at the cost of an additional buffer.

    See Also:
        `API Pipe <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1Pipe.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.Pipe'
    __ooo_type_name__: str = 'service'


__all__ = ['Pipe']

