# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from .x_number_format_previewer import XNumberFormatPreviewer as XNumberFormatPreviewer_3a570fa9
from .x_number_formatter import XNumberFormatter as XNumberFormatter_e3170d3b

class XNumberFormatter2(XNumberFormatPreviewer_3a570fa9, XNumberFormatter_e3170d3b):
    """
    Provides a unified interface for the NumberFormatter service to implement.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XNumberFormatter2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormatter2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XNumberFormatter2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XNumberFormatter2'


__all__ = ['XNumberFormatter2']

