# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from .x_layout_manager2 import XLayoutManager2 as XLayoutManager2_e1270cd6

class LayoutManager(XLayoutManager2_e1270cd6):
    """
    Service Class

    controls the layout of user interface elements which are part of a frame.
    
    Layout management is the process of determining the size and position of user interface elements. By default, each Frame has a layout manager – it performs layout management for the user interface elements within the frame. User interface elements can provide size and alignment hints to layout managers, but layout managers have the final decision on the size and position of those user interface elements.
    
    Available properties:
    
    **since**
    
        OOo 2.0

    See Also:
        `API LayoutManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1LayoutManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.LayoutManager'
    __ooo_type_name__: str = 'service'


__all__ = ['LayoutManager']

