# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.awt.MenuItemType import MenuItemTypeProto

class MenuItemType(Enum):
    """
    Enum Class


    See Also:
        `API MenuItemType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt.html#a0014b68cdf9686458deff56691368317>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.MenuItemType'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.awt.MenuItemType'

    DONTKNOW = cast("MenuItemTypeProto", 'DONTKNOW')
    """
    specifies a font with an unknown slant.
    
    specifies that the menu item type is unknown.
    """
    IMAGE = cast("MenuItemTypeProto", 'IMAGE')
    """
    specifies that the menu item has an image.
    """
    SEPARATOR = cast("MenuItemTypeProto", 'SEPARATOR')
    """
    specifies that the menu item is a separator.
    """
    STRING = cast("MenuItemTypeProto", 'STRING')
    """
    specifies that the menu item has a text.
    """
    STRINGIMAGE = cast("MenuItemTypeProto", 'STRINGIMAGE')
    """
    specifies that the menu item has a text and an image.
    """

__all__ = ['MenuItemType']

