# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from .chart_data import ChartData as ChartData_98ce0a86
from .x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd

class ChartDataArray(ChartData_98ce0a86, XChartDataArray_df4c0cdd):
    """
    Service Class

    must be supported by each data source for charts, where you want to access the values directly.
    
    It contains the data values as well as the descriptions for each row and column.

    See Also:
        `API ChartDataArray <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartDataArray.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartDataArray'
    __ooo_type_name__: str = 'service'


__all__ = ['ChartDataArray']

