# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.datatransfer.dnd.dnd_constants import DNDConstants as DNDConstants
from ....lo.datatransfer.dnd.drag_gesture_event import DragGestureEvent as DragGestureEvent
from ....lo.datatransfer.dnd.drag_source_drag_event import DragSourceDragEvent as DragSourceDragEvent
from ....lo.datatransfer.dnd.drag_source_drop_event import DragSourceDropEvent as DragSourceDropEvent
from ....lo.datatransfer.dnd.drag_source_event import DragSourceEvent as DragSourceEvent
from ....lo.datatransfer.dnd.drop_target_drag_enter_event import DropTargetDragEnterEvent as DropTargetDragEnterEvent
from ....lo.datatransfer.dnd.drop_target_drag_event import DropTargetDragEvent as DropTargetDragEvent
from ....lo.datatransfer.dnd.drop_target_drop_event import DropTargetDropEvent as DropTargetDropEvent
from ....lo.datatransfer.dnd.drop_target_event import DropTargetEvent as DropTargetEvent
from ....lo.datatransfer.dnd.invalid_dnd_operation_exception import InvalidDNDOperationException as InvalidDNDOperationException
from ....lo.datatransfer.dnd.ole_drag_source import OleDragSource as OleDragSource
from ....lo.datatransfer.dnd.ole_drop_target import OleDropTarget as OleDropTarget
from ....lo.datatransfer.dnd.x11_drag_source import X11DragSource as X11DragSource
from ....lo.datatransfer.dnd.x11_drop_target import X11DropTarget as X11DropTarget
from ....lo.datatransfer.dnd.x_autoscroll import XAutoscroll as XAutoscroll
from ....lo.datatransfer.dnd.x_drag_gesture_listener import XDragGestureListener as XDragGestureListener
from ....lo.datatransfer.dnd.x_drag_gesture_recognizer import XDragGestureRecognizer as XDragGestureRecognizer
from ....lo.datatransfer.dnd.x_drag_source import XDragSource as XDragSource
from ....lo.datatransfer.dnd.x_drag_source_context import XDragSourceContext as XDragSourceContext
from ....lo.datatransfer.dnd.x_drag_source_listener import XDragSourceListener as XDragSourceListener
from ....lo.datatransfer.dnd.x_drop_target import XDropTarget as XDropTarget
from ....lo.datatransfer.dnd.x_drop_target_drag_context import XDropTargetDragContext as XDropTargetDragContext
from ....lo.datatransfer.dnd.x_drop_target_drop_context import XDropTargetDropContext as XDropTargetDropContext
from ....lo.datatransfer.dnd.x_drop_target_listener import XDropTargetListener as XDropTargetListener
