# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.table.accessible_cell_view import AccessibleCellView as AccessibleCellView
from ...lo.table.accessible_table_view import AccessibleTableView as AccessibleTableView
from ...lo.table.border_line import BorderLine as BorderLine
from ...lo.table.border_line2 import BorderLine2 as BorderLine2
from ...lo.table.border_line_style import BorderLineStyle as BorderLineStyle
from ...lo.table.cell import Cell as Cell
from ...lo.table.cell_address import CellAddress as CellAddress
from ...lo.table.cell_content_type import CellContentType as CellContentType
from ...lo.table.cell_cursor import CellCursor as CellCursor
from ...lo.table.cell_hori_justify import CellHoriJustify as CellHoriJustify
from ...lo.table.cell_justify_method import CellJustifyMethod as CellJustifyMethod
from ...lo.table.cell_orientation import CellOrientation as CellOrientation
from ...lo.table.cell_properties import CellProperties as CellProperties
from ...lo.table.cell_range import CellRange as CellRange
from ...lo.table.cell_range_address import CellRangeAddress as CellRangeAddress
from ...lo.table.cell_range_list_source import CellRangeListSource as CellRangeListSource
from ...lo.table.cell_value_binding import CellValueBinding as CellValueBinding
from ...lo.table.cell_vert_justify import CellVertJustify as CellVertJustify
from ...lo.table.cell_vert_justify2 import CellVertJustify2 as CellVertJustify2
from ...lo.table.list_position_cell_binding import ListPositionCellBinding as ListPositionCellBinding
from ...lo.table.shadow_format import ShadowFormat as ShadowFormat
from ...lo.table.shadow_location import ShadowLocation as ShadowLocation
from ...lo.table.table_border import TableBorder as TableBorder
from ...lo.table.table_border2 import TableBorder2 as TableBorder2
from ...lo.table.table_border_distances import TableBorderDistances as TableBorderDistances
from ...lo.table.table_chart import TableChart as TableChart
from ...lo.table.table_charts import TableCharts as TableCharts
from ...lo.table.table_charts_enumeration import TableChartsEnumeration as TableChartsEnumeration
from ...lo.table.table_column import TableColumn as TableColumn
from ...lo.table.table_columns import TableColumns as TableColumns
from ...lo.table.table_columns_enumeration import TableColumnsEnumeration as TableColumnsEnumeration
from ...lo.table.table_orientation import TableOrientation as TableOrientation
from ...lo.table.table_row import TableRow as TableRow
from ...lo.table.table_rows import TableRows as TableRows
from ...lo.table.table_rows_enumeration import TableRowsEnumeration as TableRowsEnumeration
from ...lo.table.table_sort_descriptor import TableSortDescriptor as TableSortDescriptor
from ...lo.table.table_sort_descriptor2 import TableSortDescriptor2 as TableSortDescriptor2
from ...lo.table.table_sort_field import TableSortField as TableSortField
from ...lo.table.table_sort_field_type import TableSortFieldType as TableSortFieldType
from ...lo.table.x_auto_formattable import XAutoFormattable as XAutoFormattable
from ...lo.table.x_cell import XCell as XCell
from ...lo.table.x_cell2 import XCell2 as XCell2
from ...lo.table.x_cell_cursor import XCellCursor as XCellCursor
from ...lo.table.x_cell_range import XCellRange as XCellRange
from ...lo.table.x_column_row_range import XColumnRowRange as XColumnRowRange
from ...lo.table.x_mergeable_cell import XMergeableCell as XMergeableCell
from ...lo.table.x_mergeable_cell_range import XMergeableCellRange as XMergeableCellRange
from ...lo.table.x_table import XTable as XTable
from ...lo.table.x_table_chart import XTableChart as XTableChart
from ...lo.table.x_table_charts import XTableCharts as XTableCharts
from ...lo.table.x_table_charts_supplier import XTableChartsSupplier as XTableChartsSupplier
from ...lo.table.x_table_columns import XTableColumns as XTableColumns
from ...lo.table.x_table_pivot_chart import XTablePivotChart as XTablePivotChart
from ...lo.table.x_table_pivot_charts import XTablePivotCharts as XTablePivotCharts
from ...lo.table.x_table_pivot_charts_supplier import XTablePivotChartsSupplier as XTablePivotChartsSupplier
from ...lo.table.x_table_rows import XTableRows as XTableRows
