# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class LinkTargets(XNameAccess_e2ab0cf6):
    """
    Service Class

    This service gives access to a collection of names that are child links of the parent object that supplied this service.
    
    The com.sun.star.container.XNameAccess returns elements of com.sun.star.beans.XPropertySet that implement the service LinkTarget.

    See Also:
        `API LinkTargets <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1LinkTargets.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.LinkTargets'
    __ooo_type_name__: str = 'service'


__all__ = ['LinkTargets']

