# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..awt.x_key_handler import XKeyHandler as XKeyHandler_98520a93
from ..awt.x_mouse_click_handler import XMouseClickHandler as XMouseClickHandler_edcb0d59
from ..awt.x_mouse_motion_handler import XMouseMotionHandler as XMouseMotionHandler_fd550de9
from ..frame.x_dispatch import XDispatch as XDispatch_98ff0a9b
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_service_info import XServiceInfo as XServiceInfo_af180b5f
from ..view.x_selection_change_listener import XSelectionChangeListener as XSelectionChangeListener_58bf104d

class XSelectionFunction(XKeyHandler_98520a93, XMouseClickHandler_edcb0d59, XMouseMotionHandler_fd550de9, XDispatch_98ff0a9b, XComponent_98dc0ab5, XServiceInfo_af180b5f, XSelectionChangeListener_58bf104d):
    """

    See Also:
        `API XSelectionFunction <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XSelectionFunction.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XSelectionFunction'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XSelectionFunction'


__all__ = ['XSelectionFunction']

