# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from .data_importer import DataImporter as DataImporter_b39c1242

class LocalDataImporter(DataImporter_b39c1242):
    """
    Service Class

    allows importing data from a local configuration data repository or file into any Backend.
    
    Data to be imported can be a single layer either from a full local configuration database or from a particular OOR Update XML file.
    
    Data is imported into the DefaultBackend.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API LocalDataImporter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1LocalDataImporter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.LocalDataImporter'
    __ooo_type_name__: str = 'service'


__all__ = ['LocalDataImporter']

