# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.xml.crypto.cipher_id import CipherID as CipherID
from ....lo.xml.crypto.digest_id import DigestID as DigestID
from ....lo.xml.crypto.gpgse_initializer import GPGSEInitializer as GPGSEInitializer
from ....lo.xml.crypto.nss_initializer import NSSInitializer as NSSInitializer
from ....lo.xml.crypto.nss_profile import NSSProfile as NSSProfile
from ....lo.xml.crypto.se_initializer import SEInitializer as SEInitializer
from ....lo.xml.crypto.security_environment import SecurityEnvironment as SecurityEnvironment
from ....lo.xml.crypto.security_operation_status import SecurityOperationStatus as SecurityOperationStatus
from ....lo.xml.crypto.x_certificate_creator import XCertificateCreator as XCertificateCreator
from ....lo.xml.crypto.x_cipher_context import XCipherContext as XCipherContext
from ....lo.xml.crypto.x_cipher_context_supplier import XCipherContextSupplier as XCipherContextSupplier
from ....lo.xml.crypto.x_digest_context import XDigestContext as XDigestContext
from ....lo.xml.crypto.x_digest_context_supplier import XDigestContextSupplier as XDigestContextSupplier
from ....lo.xml.crypto.xml_encryption_exception import XMLEncryptionException as XMLEncryptionException
from ....lo.xml.crypto.xml_security_context import XMLSecurityContext as XMLSecurityContext
from ....lo.xml.crypto.xml_signature import XMLSignature as XMLSignature
from ....lo.xml.crypto.xml_signature_exception import XMLSignatureException as XMLSignatureException
from ....lo.xml.crypto.xnss_initializer import XNSSInitializer as XNSSInitializer
from ....lo.xml.crypto.xse_initializer import XSEInitializer as XSEInitializer
from ....lo.xml.crypto.x_security_environment import XSecurityEnvironment as XSecurityEnvironment
from ....lo.xml.crypto.x_uri_binding import XUriBinding as XUriBinding
from ....lo.xml.crypto.xxml_encryption import XXMLEncryption as XXMLEncryption
from ....lo.xml.crypto.xxml_encryption_template import XXMLEncryptionTemplate as XXMLEncryptionTemplate
from ....lo.xml.crypto.xxml_security_context import XXMLSecurityContext as XXMLSecurityContext
from ....lo.xml.crypto.xxml_security_template import XXMLSecurityTemplate as XXMLSecurityTemplate
from ....lo.xml.crypto.xxml_signature import XXMLSignature as XXMLSignature
from ....lo.xml.crypto.xxml_signature_template import XXMLSignatureTemplate as XXMLSignatureTemplate
