# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.smarttags.smart_tag_action import SmartTagAction as SmartTagAction
from ...lo.smarttags.smart_tag_recognizer import SmartTagRecognizer as SmartTagRecognizer
from ...lo.smarttags.smart_tag_recognizer_mode import SmartTagRecognizerMode as SmartTagRecognizerMode
from ...lo.smarttags.x_range_based_smart_tag_recognizer import XRangeBasedSmartTagRecognizer as XRangeBasedSmartTagRecognizer
from ...lo.smarttags.x_smart_tag_action import XSmartTagAction as XSmartTagAction
from ...lo.smarttags.x_smart_tag_recognizer import XSmartTagRecognizer as XSmartTagRecognizer
