# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script.provider
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ...uno.exception import Exception as Exception_85530a09
from ...uno.x_interface import XInterface as XInterface_8f010a43

class ScriptFrameworkErrorException(Exception_85530a09):
    """
    Exception Class

    is a checked exception that represents an error encountered by the Scripting Framework whilst executing a script

    See Also:
        `API ScriptFrameworkErrorException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptFrameworkErrorException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.script.provider'
    __ooo_full_ns__: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'
    __pyunostruct__: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'

    typeName: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'
    """Literal Constant ``com.sun.star.script.provider.ScriptFrameworkErrorException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, scriptName: typing.Optional[str] = '', language: typing.Optional[str] = '', errorType: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            scriptName (str, optional): scriptName value.
            language (str, optional): language value.
            errorType (int, optional): errorType value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "scriptName": scriptName,
            "language": language,
            "errorType": errorType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._script_name = kwargs["scriptName"]
        self._language = kwargs["language"]
        self._error_type = kwargs["errorType"]
        inst_keys = ('scriptName', 'language', 'errorType')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def scriptName(self) -> str:
        """
        Name of script where error occurred.
        """
        return self._script_name
    
    @scriptName.setter
    def scriptName(self, value: str) -> None:
        self._script_name = value

    @property
    def language(self) -> str:
        """
        Scripting language of script that generated exception.
        """
        return self._language
    
    @language.setter
    def language(self, value: str) -> None:
        self._language = value

    @property
    def errorType(self) -> int:
        """
        error type com.sun.star.script.provider.ScriptFrameworkErrorType
        """
        return self._error_type
    
    @errorType.setter
    def errorType(self, value: int) -> None:
        self._error_type = value


__all__ = ['ScriptFrameworkErrorException']

