# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class PolygonFlags(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.PolygonFlags", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.PolygonFlags`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.PolygonFlags import CONTROL as POLYGON_FLAGS_CONTROL
        from com.sun.star.drawing.PolygonFlags import NORMAL as POLYGON_FLAGS_NORMAL
        from com.sun.star.drawing.PolygonFlags import SMOOTH as POLYGON_FLAGS_SMOOTH
        from com.sun.star.drawing.PolygonFlags import SYMMETRIC as POLYGON_FLAGS_SYMMETRIC

        class PolygonFlags(uno.Enum):
            """
            Enum Class


            See Also:
                `API PolygonFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#af3965fa427851bc02bfe32c5d95d7406>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.PolygonFlags', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.PolygonFlags'
            __ooo_type_name__: str = 'enum'

            CONTROL = POLYGON_FLAGS_CONTROL
            """
            the point is a control point, to control the curve from the user interface.
            """
            NORMAL = POLYGON_FLAGS_NORMAL
            """
            the text is drawn along the path without scaling.

            the point is normal, from the curve discussion view.
            """
            SMOOTH = POLYGON_FLAGS_SMOOTH
            """
            the point is smooth, the first derivation from the curve discussion view.

            With SMOOTH shading, the colors of the lit vertices is interpolated.
            """
            SYMMETRIC = POLYGON_FLAGS_SYMMETRIC
            """
            the point is symmetric, the second derivation from the curve discussion view.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.polygon_flags import PolygonFlags as PolygonFlags


__all__ = ['PolygonFlags']
