# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.xsd.boolean import Boolean as Boolean
from ...lo.xsd.data_type_class import DataTypeClass as DataTypeClass
from ...lo.xsd.date import Date as Date
from ...lo.xsd.date_time import DateTime as DateTime
from ...lo.xsd.day import Day as Day
from ...lo.xsd.decimal import Decimal as Decimal
from ...lo.xsd.month import Month as Month
from ...lo.xsd.string import String as String
from ...lo.xsd.time import Time as Time
from ...lo.xsd.white_space_treatment import WhiteSpaceTreatment as WhiteSpaceTreatment
from ...lo.xsd.x_data_type import XDataType as XDataType
from ...lo.xsd.year import Year as Year
