# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class NumberFormatProperties(ABC):
    """
    Service Class

    contains properties specifying the behavior of a NumberFormatter.

    See Also:
        `API NumberFormatProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.NumberFormatProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Comment(self) -> str:
        """
        contains a comment regarding the number format for display to the user.
        """
        ...

    @abstractproperty
    def FormatString(self) -> str:
        """
        contains the format string of the number format.
        """
        ...

    @abstractproperty
    def Locale(self) -> Locale_70d308fa:
        """
        contains the locale of the number format.
        """
        ...

    @abstractproperty
    def Type(self) -> int:
        """
        contains the type of the number format.
        """
        ...


__all__ = ['NumberFormatProperties']

