# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class ModuleUICommandDescription(XNameAccess_e2ab0cf6):
    """
    Service Class

    a service which provides information about the user interface commands of a single module.
    
    Every OpenOffice.org module has an amount of commands that can be used by user interface elements. This service provides access to the user interface commands that are part of a single OpenOffice.org module, like Writer or Calc.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ModuleUICommandDescription <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ModuleUICommandDescription.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ModuleUICommandDescription'
    __ooo_type_name__: str = 'service'


__all__ = ['ModuleUICommandDescription']

