# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
from __future__ import annotations
import typing
from abc import abstractproperty
from .service_manager import ServiceManager as ServiceManager_c7920c36
from .x_initialization import XInitialization as XInitialization_d46c0cca
if typing.TYPE_CHECKING:
    from ..registry.x_simple_registry import XSimpleRegistry as XSimpleRegistry_10150e9c

class RegistryServiceManager(ServiceManager_c7920c36, XInitialization_d46c0cca):
    """
    Service Class

    Provides a collection of implementations for services reading from a persistent registry storage.
    
    For usage of the service manager have a look at service description of ServiceManager.

    See Also:
        `API RegistryServiceManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1lang_1_1RegistryServiceManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.RegistryServiceManager'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Registry(self) -> XSimpleRegistry_10150e9c:
        """
        Specifies the current registry to be read from.
        """
        ...


__all__ = ['RegistryServiceManager']

