# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations


class TransitionSubType(object):
    """
    Const Class


    See Also:
        `API TransitionSubType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.TransitionSubType'
    __ooo_type_name__: str = 'const'

    DEFAULT = 0
    LEFTTORIGHT = 1
    TOPTOBOTTOM = 2
    TOPLEFT = 3
    TOPRIGHT = 4
    BOTTOMRIGHT = 5
    BOTTOMLEFT = 6
    TOPCENTER = 7
    RIGHTCENTER = 8
    BOTTOMCENTER = 9
    LEFTCENTER = 10
    CORNERSIN = 11
    CORNERSOUT = 12
    VERTICAL = 13
    HORIZONTAL = 14
    DIAGONALBOTTOMLEFT = 15
    DIAGONALTOPLEFT = 16
    DOUBLEBARNDOOR = 17
    DOUBLEDIAMOND = 18
    DOWN = 19
    LEFT = 20
    UP = 21
    RIGHT = 22
    RECTANGLE = 25
    DIAMOND = 26
    CIRCLE = 27
    FOURPOINT = 28
    FIVEPOINT = 29
    SIXPOINT = 30
    HEART = 31
    KEYHOLE = 32
    CLOCKWISETWELVE = 33
    CLOCKWISETHREE = 34
    CLOCKWISESIX = 35
    CLOCKWISENINE = 36
    TWOBLADEVERTICAL = 37
    TWOBLADEHORIZONTAL = 38
    FOURBLADE = 39
    CLOCKWISETOP = 40
    CLOCKWISERIGHT = 41
    CLOCKWISEBOTTOM = 42
    CLOCKWISELEFT = 43
    CLOCKWISETOPLEFT = 44
    COUNTERCLOCKWISEBOTTOMLEFT = 45
    CLOCKWISEBOTTOMRIGHT = 46
    COUNTERCLOCKWISETOPRIGHT = 47
    CENTERTOP = 48
    CENTERRIGHT = 49
    TOP = 50
    BOTTOM = 52
    FANOUTVERTICAL = 54
    FANOUTHORIZONTAL = 55
    FANINVERTICAL = 56
    FANINHORIZONTAL = 57
    PARALLELVERTICAL = 58
    PARALLELDIAGONAL = 59
    OPPOSITEVERTICAL = 60
    OPPOSITEHORIZONTAL = 61
    PARALLELDIAGONALTOPLEFT = 62
    PARALLELDIAGONALBOTTOMLEFT = 63
    TOPLEFTHORIZONTAL = 64
    TOPLEFTDIAGONAL = 65
    TOPRIGHTDIAGONAL = 66
    BOTTOMRIGHTDIAGONAL = 67
    BOTTOMLEFTDIAGONAL = 68
    TOPLEFTCLOCKWISE = 69
    TOPRIGHTCLOCKWISE = 70
    BOTTOMRIGHTCLOCKWISE = 71
    BOTTOMLEFTCLOCKWISE = 72
    TOPLEFTCOUNTERCLOCKWISE = 73
    TOPRIGHTCOUNTERCLOCKWISE = 74
    BOTTOMRIGHTCOUNTERCLOCKWISE = 75
    BOTTOMLEFTCOUNTERCLOCKWISE = 76
    VERTICALTOPSAME = 77
    VERTICALBOTTOMSAME = 78
    VERTICALTOPLEFTOPPOSITE = 79
    VERTICALBOTTOMLEFTOPPOSITE = 80
    HORIZONTALLEFTSAME = 81
    HORIZONTALRIGHTSAME = 82
    HORIZONTALTOPLEFTOPPOSITE = 83
    HORIZONTALTOPRIGHTOPPOSITE = 84
    DIAGONALBOTTOMLEFTOPPOSITE = 85
    DIAGONALTOPLEFTOPPOSITE = 86
    TWOBOXTOP = 87
    TWOBOXBOTTOM = 88
    TWOBOXLEFT = 89
    TWOBOXRIGHT = 90
    FOURBOXVERTICAL = 91
    FOURBOXHORIZONTAL = 92
    VERTICALLEFT = 93
    VERTICALRIGHT = 94
    HORIZONTALLEFT = 95
    HORIZONTALRIGHT = 96
    FROMLEFT = 97
    FROMTOP = 98
    FROMRIGHT = 99
    FROMBOTTOM = 100
    CROSSFADE = 101
    FADETOCOLOR = 102
    FADEFROMCOLOR = 103
    FADEOVERCOLOR = 104
    THREEBLADE = 105
    EIGHTBLADE = 106
    ONEBLADE = 107
    ACROSS = 108
    TOPLEFTVERTICAL = 109
    COMBHORIZONTAL = 110
    COMBVERTICAL = 111
    IN = 112
    OUT = 113
    ROTATEIN = 114
    ROTATEOUT = 115
    FROMTOPLEFT = 116
    FROMTOPRIGHT = 117
    FROMBOTTOMLEFT = 118
    FROMBOTTOMRIGHT = 119

__all__ = ['TransitionSubType']
