# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.io.already_connected_exception import AlreadyConnectedException as AlreadyConnectedException
from ...lo.io.buffer_size_exceeded_exception import BufferSizeExceededException as BufferSizeExceededException
from ...lo.io.connect_exception import ConnectException as ConnectException
from ...lo.io.data_input_stream import DataInputStream as DataInputStream
from ...lo.io.data_output_stream import DataOutputStream as DataOutputStream
from ...lo.io.data_transfer_event import DataTransferEvent as DataTransferEvent
from ...lo.io.file_permission import FilePermission as FilePermission
from ...lo.io.io_exception import IOException as IOException
from ...lo.io.markable_input_stream import MarkableInputStream as MarkableInputStream
from ...lo.io.markable_output_stream import MarkableOutputStream as MarkableOutputStream
from ...lo.io.no_route_to_host_exception import NoRouteToHostException as NoRouteToHostException
from ...lo.io.not_connected_exception import NotConnectedException as NotConnectedException
from ...lo.io.object_input_stream import ObjectInputStream as ObjectInputStream
from ...lo.io.object_output_stream import ObjectOutputStream as ObjectOutputStream
from ...lo.io.pipe import Pipe as Pipe
from ...lo.io.pump import Pump as Pump
from ...lo.io.sequence_input_stream import SequenceInputStream as SequenceInputStream
from ...lo.io.sequence_output_stream import SequenceOutputStream as SequenceOutputStream
from ...lo.io.socket_exception import SocketException as SocketException
from ...lo.io.temp_file import TempFile as TempFile
from ...lo.io.text_input_stream import TextInputStream as TextInputStream
from ...lo.io.text_output_stream import TextOutputStream as TextOutputStream
from ...lo.io.unexpected_eof_exception import UnexpectedEOFException as UnexpectedEOFException
from ...lo.io.unknown_host_exception import UnknownHostException as UnknownHostException
from ...lo.io.wrong_format_exception import WrongFormatException as WrongFormatException
from ...lo.io.x_active_data_control import XActiveDataControl as XActiveDataControl
from ...lo.io.x_active_data_sink import XActiveDataSink as XActiveDataSink
from ...lo.io.x_active_data_source import XActiveDataSource as XActiveDataSource
from ...lo.io.x_active_data_streamer import XActiveDataStreamer as XActiveDataStreamer
from ...lo.io.x_async_output_monitor import XAsyncOutputMonitor as XAsyncOutputMonitor
from ...lo.io.x_connectable import XConnectable as XConnectable
from ...lo.io.x_data_exporter import XDataExporter as XDataExporter
from ...lo.io.x_data_importer import XDataImporter as XDataImporter
from ...lo.io.x_data_input_stream import XDataInputStream as XDataInputStream
from ...lo.io.x_data_output_stream import XDataOutputStream as XDataOutputStream
from ...lo.io.x_data_transfer_event_listener import XDataTransferEventListener as XDataTransferEventListener
from ...lo.io.x_input_stream import XInputStream as XInputStream
from ...lo.io.x_input_stream_provider import XInputStreamProvider as XInputStreamProvider
from ...lo.io.x_markable_stream import XMarkableStream as XMarkableStream
from ...lo.io.x_object_input_stream import XObjectInputStream as XObjectInputStream
from ...lo.io.x_object_output_stream import XObjectOutputStream as XObjectOutputStream
from ...lo.io.x_output_stream import XOutputStream as XOutputStream
from ...lo.io.x_persist import XPersist as XPersist
from ...lo.io.x_persist_object import XPersistObject as XPersistObject
from ...lo.io.x_pipe import XPipe as XPipe
from ...lo.io.x_seekable import XSeekable as XSeekable
from ...lo.io.x_seekable_input_stream import XSeekableInputStream as XSeekableInputStream
from ...lo.io.x_sequence_output_stream import XSequenceOutputStream as XSequenceOutputStream
from ...lo.io.x_stream import XStream as XStream
from ...lo.io.x_stream_listener import XStreamListener as XStreamListener
from ...lo.io.x_temp_file import XTempFile as XTempFile
from ...lo.io.x_text_input_stream import XTextInputStream as XTextInputStream
from ...lo.io.x_text_input_stream2 import XTextInputStream2 as XTextInputStream2
from ...lo.io.x_text_output_stream import XTextOutputStream as XTextOutputStream
from ...lo.io.x_text_output_stream2 import XTextOutputStream2 as XTextOutputStream2
from ...lo.io.x_truncate import XTruncate as XTruncate
from ...lo.io.xxml_extractor import XXMLExtractor as XXMLExtractor
