# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class ActionTriggerContainer(XContainer_d6fb0cc6, XEnumerationAccess_4bac0ffc, XIndexContainer_1c040ebe, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    describes a container of user actions.
    
    No assumption is made about any graphical representation: You could have a menu or a toolbox working with the same container describing their entries.
    
    Possible elements of the ActionTriggerContainer are

    See Also:
        `API ActionTriggerContainer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ActionTriggerContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ActionTriggerContainer'
    __ooo_type_name__: str = 'service'


__all__ = ['ActionTriggerContainer']

