# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.bridge.oleautomation
from __future__ import annotations
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XAutomationObject(XInterface_8f010a43):
    """
    a tagging interface for UNO objects which represent Automation objects.
    
    If an Automation object is bridged into the UNO environment, then the resulting UNO object does not distinguish itself from any other ordinary UNO object. However, it may be desirable to have that distinction regardless, if a UNO client needs to take particular Automation specific characteristics into account. By providing XAutomationObject an object declares to be representing an Automation object.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAutomationObject <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1XAutomationObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.bridge.oleautomation'
    __ooo_full_ns__: str = 'com.sun.star.bridge.oleautomation.XAutomationObject'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.bridge.oleautomation.XAutomationObject'


__all__ = ['XAutomationObject']

