# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text


class UserDataPart(object):
    """
    Const Class

    These constants define which part of the user data is displayed in a user data text field (service \"sun.one.text.TextField.ExtendedUser\")

    See Also:
        `API UserDataPart <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.UserDataPart'
    __ooo_type_name__: str = 'const'

    COMPANY = 0
    """
    The field shows the company name.
    """
    FIRSTNAME = 1
    """
    The field shows the first name.
    """
    NAME = 2
    """
    The field shows the name.
    """
    SHORTCUT = 3
    """
    The field shows the initials.
    """
    STREET = 4
    """
    The field shows the street.
    """
    COUNTRY = 5
    """
    The field shows the country.
    """
    ZIP = 6
    """
    The field shows the zip code.
    """
    CITY = 7
    """
    The field shows the city.
    """
    TITLE = 8
    """
    The field shows the title.
    """
    POSITION = 9
    """
    The field shows the position.
    """
    PHONE_PRIVATE = 10
    """
    The field shows the no of the private phone.
    """
    PHONE_COMPANY = 11
    """
    The field shows the number of the business phone.
    """
    FAX = 12
    """
    The field shows the fax no.
    """
    EMAIL = 13
    """
    The field shows the e-Mail.
    """
    STATE = 14
    """
    The field shows the state.
    """

__all__ = ['UserDataPart']
