# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d
from .x_database_registrations import XDatabaseRegistrations as XDatabaseRegistrations_25c20f1c
from ..uno.x_naming_service import XNamingService as XNamingService_bb9a0bdd

class XDatabaseContext(XContainer_d6fb0cc6, XEnumerationAccess_4bac0ffc, XNameAccess_e2ab0cf6, XSingleServiceFactory_27210f0d, XDatabaseRegistrations_25c20f1c, XNamingService_bb9a0bdd):
    """
    Provides an interface for the new-style DatabaseContext service to implement.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XDatabaseContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XDatabaseContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XDatabaseContext'


__all__ = ['XDatabaseContext']

