# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.auth.authentication_failed_exception import AuthenticationFailedException as AuthenticationFailedException
from ...lo.auth.invalid_argument_exception import InvalidArgumentException as InvalidArgumentException
from ...lo.auth.invalid_context_exception import InvalidContextException as InvalidContextException
from ...lo.auth.invalid_credential_exception import InvalidCredentialException as InvalidCredentialException
from ...lo.auth.invalid_principal_exception import InvalidPrincipalException as InvalidPrincipalException
from ...lo.auth.persistence_failure_exception import PersistenceFailureException as PersistenceFailureException
from ...lo.auth.sso_manager_factory import SSOManagerFactory as SSOManagerFactory
from ...lo.auth.sso_password_cache import SSOPasswordCache as SSOPasswordCache
from ...lo.auth.unsupported_exception import UnsupportedException as UnsupportedException
from ...lo.auth.xsso_acceptor_context import XSSOAcceptorContext as XSSOAcceptorContext
from ...lo.auth.xsso_context import XSSOContext as XSSOContext
from ...lo.auth.xsso_initiator_context import XSSOInitiatorContext as XSSOInitiatorContext
from ...lo.auth.xsso_manager import XSSOManager as XSSOManager
from ...lo.auth.xsso_manager_factory import XSSOManagerFactory as XSSOManagerFactory
from ...lo.auth.xsso_password_cache import XSSOPasswordCache as XSSOPasswordCache
