# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing


class ShadingPattern(object):
    """
    Const Class

    The ShadingPattern determines the background color pattern against which characters and graphics are displayed, typically in tables.
    
    The color can be no color or it can be a specific color with a transparency or pattern value.

    See Also:
        `API ShadingPattern <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.ShadingPattern'
    __ooo_type_name__: str = 'const'

    CLEAR = 0
    SOLID = 1
    PCT5 = 2
    PCT10 = 3
    PCT20 = 4
    PCT25 = 5
    PCT30 = 6
    PCT40 = 7
    PCT50 = 8
    PCT60 = 9
    PCT70 = 10
    PCT75 = 11
    PCT80 = 12
    PCT90 = 13
    HORZ_STRIPE = 14
    VERT_STRIPE = 15
    REVERSE_DIAG_STRIPE = 16
    DIAG_STRIPE = 17
    HORZ_CROSS = 18
    DIAG_CROSS = 19
    THIN_HORZ_STRIPE = 20
    THIN_VERT_STRIPE = 21
    THIN_REVERSE_DIAG_STRIPE = 22
    THIN_DIAG_STRIPE = 23
    THIN_HORZ_CROSS = 24
    THIN_DIAG_CROSS = 25
    UNUSED_1 = 26
    UNUSED_2 = 27
    UNUSED_3 = 28
    UNUSED_4 = 29
    UNUSED_5 = 30
    UNUSED_6 = 31
    UNUSED_7 = 32
    UNUSED_8 = 33
    UNUSED_9 = 34
    PCT2 = 35
    PCT7 = 36
    PCT12 = 37
    PCT15 = 38
    PCT17 = 39
    PCT22 = 40
    PCT27 = 41
    PCT32 = 42
    PCT35 = 43
    PCT37 = 44
    PCT42 = 45
    PCT45 = 46
    PCT47 = 47
    PCT52 = 48
    PCT55 = 49
    PCT57 = 50
    PCT62 = 51
    PCT65 = 52
    PCT67 = 53
    PCT72 = 54
    PCT77 = 55
    PCT82 = 56
    PCT85 = 57
    PCT87 = 58
    PCT92 = 59
    PCT95 = 60
    PCT97 = 61
    NIL = 65535

__all__ = ['ShadingPattern']
