# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .url import URL as URL_57ad07b9

class XURLTransformer(XInterface_8f010a43):
    """
    supports parsing and assembling of URLs

    See Also:
        `API XURLTransformer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XURLTransformer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XURLTransformer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XURLTransformer'

    @abstractmethod
    def assemble(self, aURL: object) -> bool:
        """
        assembles the parts of the URL specified by aURL and stores it into URL.Complete
        """
        ...
    @abstractmethod
    def getPresentation(self, aURL: URL_57ad07b9, bWithPassword: bool) -> str:
        """
        returns a representation of the URL for UI purposes only
        
        Sometimes it can be useful to show a URL on an user interface in a more \"human readable\" form. Such URL can't be used on any API call, but make it easier for the user to understand it.
        """
        ...
    @abstractmethod
    def parseSmart(self, aURL: object, sSmartProtocol: str) -> bool:
        """
        parses the string in URL.Complete, which may contain a syntactically complete URL or is specified by the provided protocol
        
        The implementation can use smart functions to correct or interpret URL.Complete if it is not a syntactically complete URL. The parts of the URL are stored in the other fields of aURL.
        """
        ...
    @abstractmethod
    def parseStrict(self, aURL: object) -> bool:
        """
        parses the string in URL.Complete which should contain a syntactically complete URL.
        
        The implementation is allowed to correct minor failures in URL.Complete if the meaning of the URL remain unchanged. Parts of the URL are stored in the other fields of aURL.
        """
        ...

__all__ = ['XURLTransformer']

