# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b
from ..accessibility.x_accessible_extended_component import XAccessibleExtendedComponent as XAccessibleExtendedComponent_539d159a

class AccessibleShape(XAccessible_1cbc0eb6, XAccessibleContext_8eae119b, XAccessibleExtendedComponent_539d159a):
    """
    Service Class

    The AccessibleShape service is implemented by UNO shapes to provide accessibility information that describe the shape's features.
    
    A UNO shape is any object that implements the com.sun.star.drawing.XShape interface.
    
    The content of a draw page is modelled as tree of accessible shapes and accessible text paragraphs. The root of this (sub-)tree is the accessible draw document view. An accessible shape implements either this service or one of the \"derived\" services AccessibleGraphicShape or AccessibleOLEShape. See the section Children in the description of the com.sun.star.accessibility.XAccessibleContext interface support for more details.
    
    There are two services that extend this one: the AccessibleGraphicShape and the AccessibleOLEShape services provide additional interfaces. See there for details.
    
    A shape object is either fully or partially visible on the screen or has set the com.sun.star.accessibility.AccessibleStateType.DEFUNC state to indicate that it is no longer actively supported by its parent.
    
    Each shape object that has not set the DEFUNC state has a valid parent. That is either the containing draw page or a group shape or a 3D scene object.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AccessibleShape'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleShape']

