# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractmethod, ABC

class XDateCategories(ABC):
    """
    Allows to set date values as categories.
    
    Can be obtained from interface XChartDocument via method getData().
    
    **since**
    
        OOo 3.4

    See Also:
        `API XDateCategories <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XDateCategories.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.XDateCategories'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.XDateCategories'

    @abstractmethod
    def getDateCategories(self) -> typing.Tuple[float, ...]:
        """
        retrieves the date values if the category x-axis id a date axis
        """
        ...
    @abstractmethod
    def setDateCategories(self, rDates: typing.Tuple[float, ...]) -> None:
        """
        sets dates as categories
        """
        ...

__all__ = ['XDateCategories']

