# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TransliterationModulesNew(metaclass=UnoEnumMeta, type_name="com.sun.star.i18n.TransliterationModulesNew", name_space="com.sun.star.i18n"):
        """Dynamically created class that represents ``com.sun.star.i18n.TransliterationModulesNew`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumHangul_ko as TRANSLITERATION_MODULES_NEW_CharToNumHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumLower_ko as TRANSLITERATION_MODULES_NEW_CharToNumLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumLower_zh_CN as TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumLower_zh_TW as TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumUpper_ko as TRANSLITERATION_MODULES_NEW_CharToNumUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumUpper_zh_CN as TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumUpper_zh_TW as TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import END_OF_MODULE as TRANSLITERATION_MODULES_NEW_END_OF_MODULE
        from com.sun.star.i18n.TransliterationModulesNew import FULLWIDTH_HALFWIDTH as TRANSLITERATION_MODULES_NEW_FULLWIDTH_HALFWIDTH
        from com.sun.star.i18n.TransliterationModulesNew import HALFWIDTH_FULLWIDTH as TRANSLITERATION_MODULES_NEW_HALFWIDTH_FULLWIDTH
        from com.sun.star.i18n.TransliterationModulesNew import HIRAGANA_KATAKANA as TRANSLITERATION_MODULES_NEW_HIRAGANA_KATAKANA
        from com.sun.star.i18n.TransliterationModulesNew import IGNORE_CASE as TRANSLITERATION_MODULES_NEW_IGNORE_CASE
        from com.sun.star.i18n.TransliterationModulesNew import IGNORE_KANA as TRANSLITERATION_MODULES_NEW_IGNORE_KANA
        from com.sun.star.i18n.TransliterationModulesNew import IGNORE_WIDTH as TRANSLITERATION_MODULES_NEW_IGNORE_WIDTH
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreBaFa_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreBaFa_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreHyuByu_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreHyuByu_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreIandEfollowedByYa_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreIandEfollowedByYa_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreIterationMark_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreIterationMark_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreKiKuFollowedBySa_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreKiKuFollowedBySa_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreMiddleDot_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreMiddleDot_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreMinusSign_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreMinusSign_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreProlongedSoundMark_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreProlongedSoundMark_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSeZe_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSeZe_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSeparator_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSeparator_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSize_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSize_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSpace_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSpace_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreTiJi_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreTiJi_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreTraditionalKana_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKana_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreTraditionalKanji_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKanji_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreZiZu_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreZiZu_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import KATAKANA_HIRAGANA as TRANSLITERATION_MODULES_NEW_KATAKANA_HIRAGANA
        from com.sun.star.i18n.TransliterationModulesNew import LOWERCASE_UPPERCASE as TRANSLITERATION_MODULES_NEW_LOWERCASE_UPPERCASE
        from com.sun.star.i18n.TransliterationModulesNew import LargeToSmall_ja_JP as TRANSLITERATION_MODULES_NEW_LargeToSmall_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharFullwidth as TRANSLITERATION_MODULES_NEW_NumToCharFullwidth
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharHangul_ko as TRANSLITERATION_MODULES_NEW_NumToCharHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharKanjiShort_ja_JP as TRANSLITERATION_MODULES_NEW_NumToCharKanjiShort_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharLower_ko as TRANSLITERATION_MODULES_NEW_NumToCharLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharLower_zh_CN as TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharLower_zh_TW as TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharUpper_ko as TRANSLITERATION_MODULES_NEW_NumToCharUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharUpper_zh_CN as TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharUpper_zh_TW as TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextFormalHangul_ko as TRANSLITERATION_MODULES_NEW_NumToTextFormalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextFormalLower_ko as TRANSLITERATION_MODULES_NEW_NumToTextFormalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextFormalUpper_ko as TRANSLITERATION_MODULES_NEW_NumToTextFormalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextInformalHangul_ko as TRANSLITERATION_MODULES_NEW_NumToTextInformalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextInformalLower_ko as TRANSLITERATION_MODULES_NEW_NumToTextInformalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextInformalUpper_ko as TRANSLITERATION_MODULES_NEW_NumToTextInformalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextLower_zh_CN as TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextLower_zh_TW as TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextUpper_zh_CN as TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextUpper_zh_TW as TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import SmallToLarge_ja_JP as TRANSLITERATION_MODULES_NEW_SmallToLarge_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumFormalHangul_ko as TRANSLITERATION_MODULES_NEW_TextToNumFormalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumFormalLower_ko as TRANSLITERATION_MODULES_NEW_TextToNumFormalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumFormalUpper_ko as TRANSLITERATION_MODULES_NEW_TextToNumFormalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumInformalHangul_ko as TRANSLITERATION_MODULES_NEW_TextToNumInformalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumInformalLower_ko as TRANSLITERATION_MODULES_NEW_TextToNumInformalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumInformalUpper_ko as TRANSLITERATION_MODULES_NEW_TextToNumInformalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumLower_zh_CN as TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumLower_zh_TW as TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumUpper_zh_CN as TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumUpper_zh_TW as TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import UPPERCASE_LOWERCASE as TRANSLITERATION_MODULES_NEW_UPPERCASE_LOWERCASE

        class TransliterationModulesNew(uno.Enum):
            """
            Enum Class


            See Also:
                `API TransliterationModulesNew <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.i18n.TransliterationModulesNew', value)

            __ooo_ns__: str = 'com.sun.star.i18n'
            __ooo_full_ns__: str = 'com.sun.star.i18n.TransliterationModulesNew'
            __ooo_type_name__: str = 'enum'

            CharToNumHangul_ko = TRANSLITERATION_MODULES_NEW_CharToNumHangul_ko
            """
            Transliterate a Korean Hangul number string to ASCII number string.
            """
            CharToNumLower_ko = TRANSLITERATION_MODULES_NEW_CharToNumLower_ko
            """
            Transliterate a Korean Hanja lower case number string to ASCII number string.
            """
            CharToNumLower_zh_CN = TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_CN
            """
            Transliterate a Simplified Chinese lower case number string to ASCII number string.
            """
            CharToNumLower_zh_TW = TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_TW
            """
            Transliterate a Traditional Chinese lower case number string to ASCII number string.
            """
            CharToNumUpper_ko = TRANSLITERATION_MODULES_NEW_CharToNumUpper_ko
            """
            Transliterate a Korean Hanja upper case number string to ASCII number string.
            """
            CharToNumUpper_zh_CN = TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_CN
            """
            Transliterate a Simplified Chinese upper case number string to ASCII number string.
            """
            CharToNumUpper_zh_TW = TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_TW
            """
            Transliterate a Traditional Chinese upper case number string to ASCII number string.
            """
            END_OF_MODULE = TRANSLITERATION_MODULES_NEW_END_OF_MODULE
            """
            """
            FULLWIDTH_HALFWIDTH = TRANSLITERATION_MODULES_NEW_FULLWIDTH_HALFWIDTH
            """
            Transliterate a string from full width character to half width character.
            """
            HALFWIDTH_FULLWIDTH = TRANSLITERATION_MODULES_NEW_HALFWIDTH_FULLWIDTH
            """
            Transliterate a string from half width character to full width character.
            """
            HIRAGANA_KATAKANA = TRANSLITERATION_MODULES_NEW_HIRAGANA_KATAKANA
            """
            Transliterate a Japanese string from Hiragana to Katakana.
            """
            IGNORE_CASE = TRANSLITERATION_MODULES_NEW_IGNORE_CASE
            """
            Ignore case when comparing strings by transliteration service.
            """
            IGNORE_KANA = TRANSLITERATION_MODULES_NEW_IGNORE_KANA
            """
            Ignore Hiragana and Katakana when comparing strings by transliteration service.
            """
            IGNORE_WIDTH = TRANSLITERATION_MODULES_NEW_IGNORE_WIDTH
            """
            Ignore full width and half width character when comparing strings by transliteration service.

            Ignore full width and half width characters when comparing strings by transliteration service.
            """
            IgnoreBaFa_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreBaFa_ja_JP
            """
            Ignore Katakana and Hiragana Ba/Gua and Ha/Fa in Japanese fuzzy search.
            """
            IgnoreHyuByu_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreHyuByu_ja_JP
            """
            Ignore Katakana and Hiragana Hyu/Fyu and Byu/Gyu in Japanese fuzzy search.
            """
            IgnoreIandEfollowedByYa_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreIandEfollowedByYa_ja_JP
            """
            Ignore Katakana YA/A which follows the character in either I or E row in Japanese fuzzy search.

            Ignore Katakana YA/A following the character in either I or E row in Japanese fuzzy search.
            """
            IgnoreIterationMark_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreIterationMark_ja_JP
            """
            Ignore Hiragana and Katakana iteration mark in Japanese fuzzy search.
            """
            IgnoreKiKuFollowedBySa_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreKiKuFollowedBySa_ja_JP
            """
            Ignore Katakana KI/KU which follows the character in SA column in Japanese fuzzy search.

            Ignore Katakana KI/KU following the character in SA column in Japanese fuzzy search.
            """
            IgnoreMiddleDot_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreMiddleDot_ja_JP
            """
            Ignore middle dot in Japanese fuzzy search.
            """
            IgnoreMinusSign_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreMinusSign_ja_JP
            """
            Ignore dash or minus sign in Japanese fuzzy search.
            """
            IgnoreProlongedSoundMark_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreProlongedSoundMark_ja_JP
            """
            Ignore Japanese prolonged sound mark in Japanese fuzzy search.
            """
            IgnoreSeZe_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSeZe_ja_JP
            """
            Ignore Katakana and Hiragana Se/Sye and Ze/Je in Japanese fuzzy search.
            """
            IgnoreSeparator_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSeparator_ja_JP
            """
            Ignore separator punctuations in Japanese fuzzy search.
            """
            IgnoreSize_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSize_ja_JP
            """
            Ignore Japanese normal and small sized character in Japanese fuzzy search.
            """
            IgnoreSpace_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSpace_ja_JP
            """
            Ignore white space characters, include space, TAB, return, etc. in Japanese fuzzy search.
            """
            IgnoreTiJi_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreTiJi_ja_JP
            """
            Ignore Katakana and Hiragana Tsui/Tea/Ti and Dyi/Ji in Japanese fuzzy search.
            """
            IgnoreTraditionalKana_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKana_ja_JP
            """
            Ignore Japanese traditional Katakana and Hiragana character in Japanese fuzzy search.

            Ignore Japanese traditional Katakana and Hiragana characters in Japanese fuzzy search.
            """
            IgnoreTraditionalKanji_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKanji_ja_JP
            """
            Ignore Japanese traditional Kanji character in Japanese fuzzy search.

            Ignore Japanese traditional Kanji characters in Japanese fuzzy search.
            """
            IgnoreZiZu_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreZiZu_ja_JP
            """
            Ignore Katakana and Hiragana Zi/Zi and Zu/Zu in Japanese fuzzy search.
            """
            KATAKANA_HIRAGANA = TRANSLITERATION_MODULES_NEW_KATAKANA_HIRAGANA
            """
            Transliterate a Japanese string from Katakana to Hiragana.
            """
            LOWERCASE_UPPERCASE = TRANSLITERATION_MODULES_NEW_LOWERCASE_UPPERCASE
            """
            Transliterate a string from lower case to upper case.
            """
            LargeToSmall_ja_JP = TRANSLITERATION_MODULES_NEW_LargeToSmall_ja_JP
            """
            transliterate Japanese normal sized character to small sized character
            """
            NumToCharFullwidth = TRANSLITERATION_MODULES_NEW_NumToCharFullwidth
            """
            Transliterate a half width number string to full width number string.
            """
            NumToCharHangul_ko = TRANSLITERATION_MODULES_NEW_NumToCharHangul_ko
            """
            Transliterate an ASCII number string to Korean Hangul number string.
            """
            NumToCharKanjiShort_ja_JP = TRANSLITERATION_MODULES_NEW_NumToCharKanjiShort_ja_JP
            """
            Transliterate an ASCII number string to Japanese Kanji number string.
            """
            NumToCharLower_ko = TRANSLITERATION_MODULES_NEW_NumToCharLower_ko
            """
            Transliterate an ASCII number string to Korean Hanja lower case number string.
            """
            NumToCharLower_zh_CN = TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese lower case number string.
            """
            NumToCharLower_zh_TW = TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese lower case number string.
            """
            NumToCharUpper_ko = TRANSLITERATION_MODULES_NEW_NumToCharUpper_ko
            """
            Transliterate an ASCII number string to Korean Hanja upper case number string.
            """
            NumToCharUpper_zh_CN = TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese upper case number string.
            """
            NumToCharUpper_zh_TW = TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese upper case number string.
            """
            NumToTextFormalHangul_ko = TRANSLITERATION_MODULES_NEW_NumToTextFormalHangul_ko
            """
            Transliterate an ASCII number string to formal Korean Hangul number string in spellout format.
            """
            NumToTextFormalLower_ko = TRANSLITERATION_MODULES_NEW_NumToTextFormalLower_ko
            """
            Transliterate an ASCII number string to formal Korean Hanja lower case number string in spellout format.
            """
            NumToTextFormalUpper_ko = TRANSLITERATION_MODULES_NEW_NumToTextFormalUpper_ko
            """
            Transliterate an ASCII number string to formal Korean Hanja upper case number string in spellout format.
            """
            NumToTextInformalHangul_ko = TRANSLITERATION_MODULES_NEW_NumToTextInformalHangul_ko
            """
            Transliterate an ASCII number string to informal Korean Hangul number string in spellout format.
            """
            NumToTextInformalLower_ko = TRANSLITERATION_MODULES_NEW_NumToTextInformalLower_ko
            """
            Transliterate an ASCII number string to informal Korean Hanja lower case number string in spellout format.
            """
            NumToTextInformalUpper_ko = TRANSLITERATION_MODULES_NEW_NumToTextInformalUpper_ko
            """
            Transliterate an ASCII number string to informal Korean Hanja upper case number string in spellout format.
            """
            NumToTextLower_zh_CN = TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese lower case number string in spellout format.
            """
            NumToTextLower_zh_TW = TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese lower case number string in spellout format.
            """
            NumToTextUpper_zh_CN = TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese upper case number string in spellout format.
            """
            NumToTextUpper_zh_TW = TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese upper case number string in spellout format.
            """
            SmallToLarge_ja_JP = TRANSLITERATION_MODULES_NEW_SmallToLarge_ja_JP
            """
            transliterate Japanese small sized character to normal sized character
            """
            TextToNumFormalHangul_ko = TRANSLITERATION_MODULES_NEW_TextToNumFormalHangul_ko
            """
            Transliterate a Korean formal Hangul number string (spellout) to ASCII number string.
            """
            TextToNumFormalLower_ko = TRANSLITERATION_MODULES_NEW_TextToNumFormalLower_ko
            """
            Transliterate a Korean formal Hanja lower case number string (spellout) to ASCII number string.
            """
            TextToNumFormalUpper_ko = TRANSLITERATION_MODULES_NEW_TextToNumFormalUpper_ko
            """
            Transliterate a Korean formal Hanja upper case number string (spellout) to ASCII number string.
            """
            TextToNumInformalHangul_ko = TRANSLITERATION_MODULES_NEW_TextToNumInformalHangul_ko
            """
            Transliterate a Korean informal Hangul number string (spellout) to ASCII number string.
            """
            TextToNumInformalLower_ko = TRANSLITERATION_MODULES_NEW_TextToNumInformalLower_ko
            """
            Transliterate a Korean informal Hanja lower case number string (spellout) to ASCII number string.
            """
            TextToNumInformalUpper_ko = TRANSLITERATION_MODULES_NEW_TextToNumInformalUpper_ko
            """
            Transliterate a Korean informal Hanja upper case number string (spellout) to ASCII number string.
            """
            TextToNumLower_zh_CN = TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_CN
            """
            Transliterate a Simplified Chinese lower case number string (spellout) to ASCII number string.
            """
            TextToNumLower_zh_TW = TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_TW
            """
            Transliterate a Traditional Chinese lower case number string (spellout) to ASCII number string.
            """
            TextToNumUpper_zh_CN = TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_CN
            """
            Transliterate a Simplified Chinese upper case number string (spellout) to ASCII number string.
            """
            TextToNumUpper_zh_TW = TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_TW
            """
            Transliterate a Traditional Chinese upper case number string (spellout) to ASCII number string.
            """
            UPPERCASE_LOWERCASE = TRANSLITERATION_MODULES_NEW_UPPERCASE_LOWERCASE
            """
            Transliterate a string from upper case to lower case.
            """
    else:
        # keep document generators happy
        from ...lo.i18n.transliteration_modules_new import TransliterationModulesNew as TransliterationModulesNew


__all__ = ['TransliterationModulesNew']
