# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.graphic
from __future__ import annotations
from .x_graphic_provider import XGraphicProvider as XGraphicProvider_b5b0e47

class GraphicProvider(XGraphicProvider_b5b0e47):
    """
    Service Class

    Central service of the Graphic API that gives access to graphics of any kind.
    
    This service allows to load graphics from and to store graphics to any location. The one and only interface that has to be implemented is the XGraphicProvider interface, that exposes the necessary methods for loading and storing the graphic contents and descriptors

    See Also:
        `API GraphicProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.graphic'
    __ooo_full_ns__: str = 'com.sun.star.graphic.GraphicProvider'
    __ooo_type_name__: str = 'service'


__all__ = ['GraphicProvider']

