# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.bridge.bridge import Bridge as Bridge
from ...lo.bridge.bridge_exists_exception import BridgeExistsException as BridgeExistsException
from ...lo.bridge.bridge_factory import BridgeFactory as BridgeFactory
from ...lo.bridge.iiop_bridge import IiopBridge as IiopBridge
from ...lo.bridge.invalid_protocol_change_exception import InvalidProtocolChangeException as InvalidProtocolChangeException
from ...lo.bridge.model_dependent import ModelDependent as ModelDependent
from ...lo.bridge.ole_application_registration import OleApplicationRegistration as OleApplicationRegistration
from ...lo.bridge.ole_bridge_supplier import OleBridgeSupplier as OleBridgeSupplier
from ...lo.bridge.ole_bridge_supplier2 import OleBridgeSupplier2 as OleBridgeSupplier2
from ...lo.bridge.ole_bridge_supplier_var1 import OleBridgeSupplierVar1 as OleBridgeSupplierVar1
from ...lo.bridge.ole_object_factory import OleObjectFactory as OleObjectFactory
from ...lo.bridge.protocol_property import ProtocolProperty as ProtocolProperty
from ...lo.bridge.uno_url_resolver import UnoUrlResolver as UnoUrlResolver
from ...lo.bridge.urp_bridge import UrpBridge as UrpBridge
from ...lo.bridge.x_bridge import XBridge as XBridge
from ...lo.bridge.x_bridge_factory import XBridgeFactory as XBridgeFactory
from ...lo.bridge.x_bridge_factory2 import XBridgeFactory2 as XBridgeFactory2
from ...lo.bridge.x_bridge_supplier import XBridgeSupplier as XBridgeSupplier
from ...lo.bridge.x_bridge_supplier2 import XBridgeSupplier2 as XBridgeSupplier2
from ...lo.bridge.x_instance_provider import XInstanceProvider as XInstanceProvider
from ...lo.bridge.x_protocol_properties import XProtocolProperties as XProtocolProperties
from ...lo.bridge.x_uno_url_resolver import XUnoUrlResolver as XUnoUrlResolver
