# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class VclWindowPeerAttribute(object):
    """
    Const Class

    specifies attributes for the VCL window implementation.
    
    IMPORTANT: These constants have to be disjunct with constants in WindowAttribute.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API VclWindowPeerAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1VclWindowPeerAttribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.VclWindowPeerAttribute'
    __ooo_type_name__: str = 'const'

    HSCROLL = 256
    VSCROLL = 512
    LEFT = 1024
    CENTER = 2048
    RIGHT = 4096
    SPIN = 8192
    SORT = 16384
    DROPDOWN = 32768
    DEFBUTTON = 65536
    READONLY = 262144
    CLIPCHILDREN = 524288
    NOBORDER = 1048576
    GROUP = 2097152
    OK = 4194304
    OK_CANCEL = 8388608
    YES_NO = 16777216
    YES_NO_CANCEL = 33554432
    RETRY_CANCEL = 67108864
    DEF_OK = 134217728
    DEF_CANCEL = 268435456
    DEF_RETRY = 536870912
    DEF_YES = 1073741824
    DEF_NO = -2147483648
    NOLABEL = 536870912
    AUTOHSCROLL = 1073741824
    AUTOVSCROLL = -2147483648

__all__ = ['VclWindowPeerAttribute']
